""" Default config
"""
default_app_config = "core_exporters_app.apps.CoreExportersAppConfig"
